@@ -25,6 +25,7 @@
 #' \item{ate}{Estimated treatment effect (difference in cumulative incidence functions).}
 #' \item{se}{Standard error of the estimated treatment effect.}
 #' \item{p.val}{P value of testing the treatment effect, which is not available under this strategy.}
+#' \item{cumhaz}{Baseline cumulative hazards in the survival models.}
 #' }
 #'
 #' @details
@@ -44,7 +45,7 @@
 #' @seealso \code{\link[tteICE]{surv.principal.eff}}, \code{\link[tteICE]{surv.tteICE}}
 #'
 #'
-#' @export
+#' @keywords internal
 
 surv.principal <- function(A,Time,cstatus,weights=rep(1,length(A))){
   n = length(A)
@@ -56,10 +57,13 @@ surv.principal <- function(A,Time,cstatus,weights=rep(1,length(A))){
   fit20 = survfitKM(factor(rep(0,n0)), Surv(Time,cstatus>1)[s0], weights=weights[s0])
   time1 = c(0, fit11$time)
   time0 = c(0, fit10$time)
+  tt = sort(unique(c(time1,time0)))
   fit11 = rbind(0,cbind(fit11$cumhaz,fit11$std.err))
   fit10 = rbind(0,cbind(fit10$cumhaz,fit10$std.err))
   fit21 = rbind(0,cbind(fit21$cumhaz,fit21$std.err))
   fit20 = rbind(0,cbind(fit20$cumhaz,fit20$std.err))
+  cumhaz = data.frame(time=tt,cumhaz11=.matchy(fit11[,1],time1,tt),cumhaz10=.matchy(fit10[,1],time0,tt),
+                      cumhaz21=.matchy(fit21[,1],time1,tt),cumhaz20=.matchy(fit20[,1],time0,tt))
   S1 = exp(-fit11[,1]-fit21[,1])
   S0 = exp(-fit10[,1]-fit20[,1])
   dcif1 = S1*diff(c(0,fit11[,1]))
@@ -68,8 +72,6 @@ surv.principal <- function(A,Time,cstatus,weights=rep(1,length(A))){
   cif0 = cumsum(dcif0)
   PR1 = min(S1 + cif1)
   PR0 = min(S0 + cif0)
-  #PR1 = 1 - sum(S1*diff(c(0,fit21[,1])))
-  #PR0 = 1 - sum(S0*diff(c(0,fit20[,1])))
   V1 = fit11[,2]^2
   V0 = fit21[,2]^2
   V1[is.infinite(V1)] = max(V1[!is.infinite(V1)])
@@ -107,9 +109,8 @@ surv.principal <- function(A,Time,cstatus,weights=rep(1,length(A))){
   se0[is.nan(se0)] = rev(na.omit(se0))[1]
   cif1 = cif1/PR1
   cif0 = cif0/PR0
-  tt = sort(unique(c(time1,time0)))
   ate = .matchy(cif1,time1,tt)-.matchy(cif0,time0,tt)
   se = sqrt(.matchy(se1,time1,tt)^2+.matchy(se0,time0,tt)^2)
   return(list(time1=time1,time0=time0,cif1=cif1,cif0=cif0,se1=se1,se0=se0,
-              time=tt,ate=ate,se=se,p.val=NULL))
+              time=tt,ate=ate,se=se,p.val=NULL,cumhaz=cumhaz))
 }
